@@ -12,6 +12,8 @@ from .forms import PartInfoForm, PartFormSemiIntelligent, AddSubpartForm, Seller
 
 from . import constants
 
+TEST_FILES_DIR = "bom/test_files"
+
 
 class TestBomAuth(TransactionTestCase):
     def setUp(self):
@@ -171,7 +173,7 @@ class TestBOM(TransactionTestCase):
         (p1, p2, p3, p4) = create_some_fake_parts(organization=self.organization)
 
         test_file = 'test_bom.csv' if self.organization.number_variation_len > 0 else 'test_bom_6_no_variations.csv'
-        with open(f'bom/test_files/{test_file}') as test_csv:
+        with open(f'{TEST_FILES_DIR}/{test_file}') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': p2.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -197,7 +199,7 @@ class TestBOM(TransactionTestCase):
         self.assertEqual(subparts[2].do_not_load, True)
 
 
-        with open('bom/test_files/test_bom_2.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_2.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': p1.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -208,7 +210,7 @@ class TestBOM(TransactionTestCase):
 
     def test_part_upload_bom_corner_cases(self):
         (p1, p2, p3, p4) = create_some_fake_parts(organization=self.organization)
-        with open('bom/test_files/test_bom_3_recursion.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_3_recursion.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': p1.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -217,7 +219,7 @@ class TestBOM(TransactionTestCase):
             self.assertEqual(msg.tags, "error")
             self.assertTrue("recursion" in str(msg.message))
 
-        with open('bom/test_files/test_bom_4_no_part_rev.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_4_no_part_rev.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': p1.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -555,7 +557,7 @@ class TestBOM(TransactionTestCase):
         create_some_fake_part_classes(self.organization)
 
         # Should pass
-        with open('bom/test_files/test_new_parts.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv}, follow=True)
         messages = list(response.context.get('messages'))
         for msg in messages:
@@ -568,7 +570,7 @@ class TestBOM(TransactionTestCase):
             self.assertIsNotNone(p.latest())
 
         # Should fail because class doesn't exist
-        with open('bom/test_files/test_new_parts_2.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_2.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv})
         self.assertEqual(response.status_code, 302)
         found_error = False
@@ -578,7 +580,7 @@ class TestBOM(TransactionTestCase):
         self.assertTrue(found_error)
 
         # Part should be skipped because it already exists
-        with open('bom/test_files/test_new_parts_3.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_3.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv})
         self.assertEqual(response.status_code, 302)
         found_error = False
@@ -591,7 +593,7 @@ class TestBOM(TransactionTestCase):
         create_some_fake_part_classes(self.organization)
 
         # Should break with data error
-        with open('bom/test_files/test_new_parts_broken.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_broken.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv}, follow=True)
         messages = list(response.context.get('messages'))
 
@@ -601,7 +603,7 @@ class TestBOM(TransactionTestCase):
 
     def test_upload_part_classes(self):
         # Should pass
-        with open('bom/test_files/test_part_classes.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_part_classes.csv') as test_csv:
             response = self.client.post(reverse('bom:settings'), {'file': test_csv, 'submit-part-class-upload': ''})
         self.assertEqual(response.status_code, 200)
 
@@ -614,20 +616,20 @@ class TestBOM(TransactionTestCase):
         self.assertEqual(response.status_code, 200)
 
         # Submit with blank header and comments
-        with open('bom/test_files/test_part_classes_no_comment.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_part_classes_no_comment.csv') as test_csv:
             response = self.client.post(reverse('bom:settings'), {'file': test_csv, 'submit-part-class-upload': ''})
         self.assertEqual(response.status_code, 200)
         self.assertTrue('Part class 102 Resistor on row 3 is already defined. Uploading of this part class skipped.' in str(response.content))
 
         # Submit with a weird csv file that sort of works
-        with open('bom/test_files/test_part_classes_blank_rows.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_part_classes_blank_rows.csv') as test_csv:
             response = self.client.post(reverse('bom:settings'), {'file': test_csv, 'submit-part-class-upload': ''})
         self.assertEqual(response.status_code, 200)
         self.assertTrue('in row 3 does not have a value. Uploading of this part class skipped.' in str(response.content))
         self.assertTrue('in row 4 does not have a value. Uploading of this part class skipped.' in str(response.content))
 
         # Submit with a csv file exported with a byte order mask, typically from MS word I think
-        with open('bom/test_files/test_part_classes_byte_order.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_part_classes_byte_order.csv') as test_csv:
             response = self.client.post(reverse('bom:settings'), {'file': test_csv, 'submit-part-class-upload': ''}, follow=True)
         self.assertEqual(response.status_code, 200)
         messages = list(response.context.get('messages'))
@@ -639,7 +641,7 @@ class TestBOM(TransactionTestCase):
         self.organization.save()
 
         # Upload part classes
-        with open('bom/test_files/test_part_classes_4.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_part_classes_4.csv') as test_csv:
             response = self.client.post(reverse('bom:settings'), {'file': test_csv, 'submit-part-class-upload': ''})
         self.assertEqual(response.status_code, 200)
 
@@ -647,7 +649,7 @@ class TestBOM(TransactionTestCase):
         self.assertEqual(new_part_class_count, 39)
 
         # Upload parts
-        with open('bom/test_files/test_new_parts_4.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_4.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv}, follow=True)
         messages = list(response.context.get('messages'))
         for msg in messages:
@@ -662,7 +664,7 @@ class TestBOM(TransactionTestCase):
         pcba_class = PartClass.objects.filter(code=652).first()
         pcba = Part.objects.filter(number_class=pcba_class, number_item='00003', number_variation='0A').first()
 
-        with open('bom/test_files/test_bom_652-00003-0A.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_652-00003-0A.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': pcba.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -678,7 +680,7 @@ class TestBOM(TransactionTestCase):
         self.assertEqual(subparts[2].reference, 'C23')
         pcba = Part.objects.filter(number_class=pcba_class, number_item='00004', number_variation='0A').first()
 
-        with open('bom/test_files/test_bom_652-00004-0A.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_652-00004-0A.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': pcba.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -1064,7 +1066,7 @@ class TestBOMIntelligent(TestBOM):
         assy = create_a_fake_assembly()
         pr6 = create_a_fake_part_revision(part=p5, assembly=assy)
 
-        with open('bom/test_files/test_bom.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': p2.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -1090,14 +1092,14 @@ class TestBOMIntelligent(TestBOM):
 
         # part_count = Part.objects.all().count()
         # Should pass
-        with open('bom/test_files/test_new_parts_5_intelligent.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_5_intelligent.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv})
         self.assertEqual(response.status_code, 302)
         new_part_count = Part.objects.all().count()
         self.assertEqual(new_part_count, 4)
 
         # Part should be skipped because it already exists
-        with open('bom/test_files/test_new_parts_5_intelligent.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_5_intelligent.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv})
         self.assertEqual(response.status_code, 302)
         found_error = False
@@ -1111,7 +1113,7 @@ class TestBOMIntelligent(TestBOM):
 
         # Uploading this BOM should work, and multiple parts should not be created
         p = Part.objects.first()
-        with open('bom/test_files/test_bom_5_intelligent.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_5_intelligent.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': p.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -1132,7 +1134,7 @@ class TestBOMIntelligent(TestBOM):
         self.organization.number_item_len = 5
         self.organization.save()
 
-        with open('bom/test_files/test_new_parts_5_intelligent.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_new_parts_5_intelligent.csv') as test_csv:
             response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv}, follow=True)
         messages = list(response.context.get('messages'))
         for msg in messages:
@@ -1144,7 +1146,7 @@ class TestBOMIntelligent(TestBOM):
 
         pcba = Part.objects.get(number_item='DYSON-123')
 
-        with open('bom/test_files/test_bom_5_intelligent.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_5_intelligent.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': pcba.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
 
@@ -1160,7 +1162,7 @@ class TestBOMIntelligent(TestBOM):
         self.assertEqual(subparts[2].reference, '')
 
         pt1, pt2, pt3, pt4 = create_some_fake_parts(self.organization)
-        with open('bom/test_files/test_bom_5_intelligent_no_reference.csv') as test_csv:
+        with open(f'{TEST_FILES_DIR}/test_bom_5_intelligent_no_reference.csv') as test_csv:
             response = self.client.post(reverse('bom:part-upload-bom', kwargs={'part_id': pt1.id}), {'file': test_csv}, follow=True)
         self.assertEqual(response.status_code, 200)
         subparts = pt1.latest().assembly.subparts.all().order_by('id')
